# Virtual Workspaces
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/virtual-workspaces#overview)
  * [Essentials](https://help.sap.com/docs/leanix/ea/virtual-workspaces#essentials)
  * [Access Control for Virtual Workspaces](https://help.sap.com/docs/leanix/ea/virtual-workspaces#access-control-for-virtual-workspaces)
  * [Access Control Behavior for Different User Roles](https://help.sap.com/docs/leanix/ea/virtual-workspaces#access-control-behavior-for-different-user-roles)
  * [User Flow for an Admin Creating a New Fact Sheet](https://help.sap.com/docs/leanix/ea/virtual-workspaces#user-flow-for-an-admin-creating-a-new-fact-sheet)
  * [User Flow for a Member Creating a New Fact Sheet](https://help.sap.com/docs/leanix/ea/virtual-workspaces#user-flow-for-a-member-creating-a-new-fact-sheet)


Manage access to fact sheets for custom user groups
